@@ -13,7 +13,7 @@ pyw.fm_free( env);
 
 ti=1
 n=4
-env = pyw.fm_init( n);
+env = pyw.fm_init( n)
 size, v = pyw.generate_fm_2additive_concave( ti,n, env)
 print( "2-additive concave FM in Mobius and its length (n=4)")
 print( v)
@@ -755,7 +755,7 @@ n = 3
 env = pyw.fm_init( n)
 
 #
-# Here the testing for env_sparse starts
+# --- Here the testing for env_sparse, n = 3 starts ---
 # 
 
 # Test wrapper for:
@@ -798,36 +798,55 @@ print( "j: ", j)
 
 # Test wrapper for:
 #    void py_populate_fm_2add_sparse_from2add(int n, double* v, struct fm_env_sparse* env)
-# n = 3
-# v = pyw.populate_fm_2add_sparse_from2add(n, v, env)
-
+n = 3
+yy, v, length = pyw.generate_fm_2additive_convex_withsomeindependent( 1, n) 
+print( "n: ", n)
+print( "v: ", v)
+pyw.populate_fm_2add_sparse_from2add( n, v, env_sparse)
 
 # Test wrapper for:
 #    void py_populate_fm_2add_sparse(double* singletons, int numpairs, double* pairs, int* indicesp1, int* indicesp2, struct fm_env_sparse* env)
-# pyw.populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, env)
-
-
+numpairs = 3
+singletons = [0.1,0.2,0.3]
+pairs = [0.4,0.5,0.6]
+indicesp1 = [1,1,2]
+indicesp2 = [2,3,3]
+pyw.populate_fm_2add_sparse(singletons, numpairs, pairs, indicesp1, indicesp2, env_sparse)
+print( "numpairs: ", numpairs)
+print( "singletons: ", singletons)
+print( "pairs: ", pairs)
+print( "indicesp1: ", indicesp1)
+print( "indicesp2: ", indicesp2)
 
 # Test wrapper for:
-#    env)void py_expand_2add_full(double* v, struct fm_env_sparse* env)
-# pyw.expand_2add_full(v, env)
+#    void py_expand_2add_full(double* out_v, struct fm_env_sparse* env)
+n = 3
+v = pyw.expand_2add_full( n, env_sparse)
+print( "n: ", n)
+print( "v: ", v)
 
+# Test wrapper for:
+#    void py_sparse_get_singletons(int n, double* out_v, struct fm_env_sparse* env)
+n = 3
+v = pyw.sparse_get_singletons(n, env_sparse)
+print( "n: ", n)
+print( "singletons: ", v)
 
 # Test wrapper for:
 #    int py_sparse_get_pairs(int* pairs, double* v, struct fm_env_sparse* env)
-# pyw.sparse_get_pairs(pairs, v, env)
+n = 3
+pairs, v = pyw.sparse_get_pairs( n, env_sparse)
+print( "n: ", n)
+print( "pairs: ", pairs)
+print( "v: ", v)
 
 # Test wrapper for:
 #    int py_sparse_get_tuples(int* tuples, double* v, struct fm_env_sparse* env)
-# pyw.sparse_get_tuples(tuples, v, env)
-
-# Test wrapper for:
-#    int   py_generate_fm_2additive_convex_sparse(int n, struct fm_env_sparse* env)
-# pyw.generate_fm_2additive_convex_sparse(n, env)
-
-# Test wrapper for:
-#    int   py_generate_fm_kadditive_convex_sparse(int n, int k, int nonzero, struct fm_env_sparse* env)
-# pyw.generate_fm_kadditive_convex_sparse(n, k, nonzero, env)
+n = 3
+tuples, v = pyw.sparse_get_tuples( n, env_sparse)
+print( "n: ", n)
+print( "tuples: ", tuples)
+print( "v: ", v)
 
 # Test wrapper for:
 #    void py_Nonmodularityindex_sparse(double* out_w, int n, struct fm_env_sparse* env)
@@ -879,12 +898,29 @@ print( "is_subset: ", is_subset)
 
 # Test wrapper for:
 #    double py_min_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
-# pyw.min_subset_sparse(x, n, S, cardS, env_sparse)
+x = [0.1,0.05,0.2]
+n = 3
+S = 0
+cardS = 3
+yy = pyw.min_subset_sparse(x, n, S, cardS, env_sparse)
+print( "x: ", x)
+print( "n: ", n)
+print( "S: ", S)
+print( "cardS: ", cardS)
+print( "yy: ", yy)
 
 # Test wrapper for:
 #    double py_max_subset_sparse(double* x, int n, int S, int cardS, struct fm_env_sparse* env)
-# pyw.max_subset_sparse(x, n, S, cardS, env_sparse)
-
+x = [0.1,0.05,0.2]
+n = 3
+S = 0
+cardS = 3
+yy =pyw.max_subset_sparse(x, n, S, cardS, env_sparse)
+print( "x: ", x)
+print( "n: ", n)
+print( "S: ", S)
+print( "cardS: ", cardS)
+print( "yy: ", yy)
 
 # Test wrapper for:
 #    double py_ChoquetMob_sparse(double* x, int n, struct fm_env_sparse* env)
@@ -896,3 +932,37 @@ print( "Choquet integral: ", c_i)
 # Test wrapper for:
 #    void py_free_fm_sparse( struct fm_env_sparse* env)
 pyw.free_fm_sparse( env_sparse)
+
+#
+# --- new env sparse for n = 5 ---
+#
+n = 5
+tupsize = 0
+env_sparse = pyw.prepare_fm_sparse( n, tupsize)
+
+# Test wrapper for:
+#    int   py_generate_fm_2additive_convex_sparse(int n, struct fm_env_sparse* env)
+yy = pyw.generate_fm_2additive_convex_sparse(n, env_sparse)
+print( "n: ", n)
+print( "yy: ", yy)
+
+# Test wrapper for:
+#    int   py_generate_fm_kadditive_convex_sparse(int n, int k, int nonzero, struct fm_env_sparse* env)
+k = 4
+nonzero = 10
+yy = pyw.generate_fm_kadditive_convex_sparse(n, k, nonzero, env_sparse)
+print( "n: ", n)
+print( "k: ", k)
+print( "nonzero: ", nonzero)
+print( "yy: ", yy)
+
+#
+# --- free env sparse for n = 5 ---
+#
+pyw.free_fm_sparse( env_sparse)
+
+
+
+
+
+
